@@ -4,11 +4,12 @@ Attributes:
     cmd_help (str): The help string to use for this command.
 
 """
+from typing import Dict, Any
 import logging
 import sys
 
 import click
-from fastapi_mvc import ClickAliasedGroup
+from fastapi_mvc.cli import ClickAliasedGroup
 from fastapi_mvc.cli.run import run
 from fastapi_mvc.cli.new import new
 from fastapi_mvc.cli.generate import get_generate_cmd
@@ -38,7 +39,7 @@ Source: https://github.com/fastapi-mvc/fastapi-mvc
     is_flag=True,
     default=False,
 )
-def cli(**options):
+def cli(**options: Dict[str, Any]) -> None:
     """Define command-line interface root.
 
     Args:
